************
Introduction
************

.. sectionauthor:: Tomas Edwardsson <tommi at tommi.org>

About pynag
===========
Pynag is a all around python interface to Nagios and bretheren (Icinga, Naemon and Shinken) as well as providing a command line interface to them for managing them.


